@@ -1,5 +1,5 @@
 from io import BytesIO
-from .base import load
+from .base import load, DEFAULT_CHECK_SIZE
 
 
 def is_png(img):
@@ -22,7 +22,7 @@ def is_png(img):
         return False
 
 
-def is_png_complete(img):
+def is_png_complete(img, strict=True, check_size=DEFAULT_CHECK_SIZE):
     """
     Checks whether the PNG image is complete.
 
@@ -32,6 +32,10 @@ def is_png_complete(img):
 
     :param img: the absolute path to the BMP image or a bytes/BytesIO object
     :type img: str or bytes or BytesIO
+    :param strict: if True then no junk data after actual data is allowed
+    :type strict: bool
+    :param check_size: the number of bytes from the end of the file to look for EOF marker
+    :type check_size: int
     :return: True if complete
     :rtype: bool
     """
@@ -40,9 +44,19 @@ def is_png_complete(img):
         if data is None:
             return False
         if data_len > 8:
-            data.seek(data_len - 8, 0)
-            marker = data.read(8)
-            return (marker[0] == 73) and (marker[1] == 69) and (marker[2] == 78) and (marker[3] == 68)
+            if strict:
+                data.seek(data_len - 8, 0)
+                marker = data.read(8)
+                return (marker[0] == 73) and (marker[1] == 69) and (marker[2] == 78) and (marker[3] == 68)
+            else:
+                if check_size > data_len:
+                    check_size = data_len
+                data.seek(data_len - check_size, 0)
+                buffer = data.read(check_size)
+                for i in range(len(buffer) - 8):
+                    if (buffer[i] == 73) and (buffer[i+1] == 69) and (buffer[i+2] == 78) and (buffer[i+3] == 68):
+                        return True
+                return False
         else:
             return False
     except:
